import React from 'react'
import { DateTime } from 'luxon'
import { TimeStep } from 'services/dataConsumptionContracts'

interface DateFormatConsumptionVisualizerProps {
  timeStep: TimeStep
  date: DateTime
}

const DateFormatConsumptionVisualizer: React.FC<DateFormatConsumptionVisualizerProps> = ({
  timeStep,
  date,
}: DateFormatConsumptionVisualizerProps) => {
  const formatDate = (timeStep: TimeStep) => {
    switch (timeStep) {
      case TimeStep.YEAR:
        return [
          date.toLocaleString({
            year: 'numeric',
          }),
          '',
        ]
      case TimeStep.MONTH:
        return [
          date.toLocaleString({
            month: 'long',
          }),
          date.toLocaleString({
            year: 'numeric',
          }),
        ]
      case TimeStep.DAY:
        return [
          date.toLocaleString({
            weekday: 'long',
            day: '2-digit',
          }),
          date.toLocaleString({
            month: 'long',
          }),
        ]
      case TimeStep.HOUR:
        return [
          date.toLocaleString({
            hour: 'numeric',
          }),
          date.toLocaleString({
            weekday: 'long',
            day: '2-digit',
            month: 'long',
          }),
        ]
      case TimeStep.HALF_AN_HOUR:
        return [
          date.toLocaleString({
            hour: 'numeric',
            minute: 'numeric',
          }),
          date.toLocaleString({
            weekday: 'long',
            day: '2-digit',
            month: 'long',
          }),
        ]
      default:
        return [date.toLocaleString(DateTime.DATETIME_SHORT), '']
    }
  }
  const formatedDate = formatDate(timeStep)

  return (
    <div className="cv-date-group">
      {formatedDate[0] && (
        <div className="cv-date text-16-bold">{formatedDate[0]}</div>
      )}
      {formatedDate[1] && (
        <div className="cv-date text-15-normal">{formatedDate[1]}</div>
      )}
    </div>
  )
}

export default DateFormatConsumptionVisualizer
